@@ -9,32 +9,40 @@ class MitsubishiTV1: public PIRKeysetMetaData
 {
 public:
   MitsubishiTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class MitsubishiTV1a: public MitsubishiTV1
 {
 public:
   MitsubishiTV1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class MitsubishiVCR1: public PIRKeysetMetaData
 {
 public:
   MitsubishiVCR1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class MitsubishiVCR1a: public MitsubishiVCR1
 {
 public:
   MitsubishiVCR1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // MITSUBISHI_H
