@@ -25,6 +25,7 @@ enum PIRMakeName{
   Emerson_Make,
   Epson_Make,
   Fortec_Make,
+  Foxtel_Make,
   GoldStar_Make,
   Grundig_Make,
   Haier_Make,
@@ -42,6 +43,7 @@ enum PIRMakeName{
   Microsoft_Make,
   Mitsubishi_Make,
   Motorola_Make,
+  NAD_Make,
   Nokia_Make,
   Onida_Make,
   Panasonic_Make,
@@ -64,6 +66,7 @@ enum PIRMakeName{
   Topfield_Make,
   Toshiba_Make,
   United_Make,
+  Universum_Make,
   Vestel_Make,
   Virgin_Make,
   Vizio_Make,
